=========
21cmfish
=========

.. image:: https://img.shields.io/travis/charlottenosam/21cmfish.svg
        :target: https://travis-ci.com/charlottenosam/21cmfish
        :alt: Pip
.. image:: https://img.shields.io/pypi/v/21cmfish.svg
        :target: https://pypi.python.org/pypi/21cmfish
        :alt: Pip
.. image:: https://readthedocs.org/projects/21cmfish/badge/?version=latest
        :target: https://21cmfish.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


A python package for doing Fisher matrix analysis with
`21cmFAST <https://github.com/21cmfast/21cmFAST/>`_.

Dependencies
------------
The main dependency is `21cmFAST <https://github.com/21cmfast/21cmFAST/>`_.
I *strongly* recommend you install ``21cmFAST`` first.


Documentation
--------------

See https://21cmfish.readthedocs.io for API documentation and a usage tutorial

Acknowledging
--------------

If you find ``21cmfish`` useful in your research please cite:

* Mason et al. 2022 (submitted)
